@@ -1,5 +1,6 @@
 use crate::completion;
 use crate::shell::completer::NuCompleter;
+use nu_ansi_term::Color;
 use nu_engine::{DefaultPalette, EvaluationContext, Painter};
 use nu_source::{Tag, Tagged};
 use std::borrow::Cow::{self, Owned};
@@ -79,7 +80,7 @@ impl rustyline::highlight::Highlighter for Helper {
     }
 
     fn highlight_hint<'h>(&self, hint: &'h str) -> Cow<'h, str> {
-        Owned("\x1b[1m".to_owned() + hint + "\x1b[m")
+        Owned(Color::DarkGray.prefix().to_string() + hint + nu_ansi_term::ansi::RESET)
     }
 
     fn highlight<'l>(&self, line: &'l str, _pos: usize) -> Cow<'l, str> {
@@ -149,6 +150,7 @@ impl rustyline::Helper for Helper {}
 #[cfg(test)]
 mod tests {
     use super::*;
+    use nu_engine::basic_evaluation_context;
     use rustyline::completion::Completer;
     use rustyline::line_buffer::LineBuffer;
 
@@ -162,7 +164,7 @@ mod tests {
         buffer.insert_str(0, text);
         buffer.set_pos(text.len() - 1);
 
-        let helper = Helper::new(EvaluationContext::basic().unwrap(), None);
+        let helper = Helper::new(basic_evaluation_context().unwrap(), None);
 
         helper.update(&mut buffer, "cd ".len(), &replacement);
 
@@ -182,7 +184,7 @@ mod tests {
         buffer.insert_str(0, text);
         buffer.set_pos(text.len() - 30);
 
-        let helper = Helper::new(EvaluationContext::basic().unwrap(), None);
+        let helper = Helper::new(basic_evaluation_context().unwrap(), None);
 
         helper.update(&mut buffer, "cd ".len(), &replacement);
 
